@@ -10,7 +10,7 @@ nox.options.stop_on_first_error = True
 nox.options.reuse_existing_virtualenvs = True
 
 
-BLACK_SPEC = "black==21.11b1"
+BLACK_SPEC = "black>=22.3.0"
 ISORT_SPEC = "isort==5.6.3"
 PYTEST_MOCK_SPEC = "pytest-mock==3.3.1"
 
@@ -29,6 +29,13 @@ class Parser(argparse.ArgumentParser):
     def __init__(self):
         super().__init__()
 
+        self.add_argument(
+            "-e",
+            "--editable",
+            action="store_true",
+            default=False,
+        )
+
         test_group = self.add_argument_group("test")
         test_group.add_argument(
             "--test-groups",
@@ -89,7 +96,10 @@ def reformat(session):
 def docs(session):
     args = Parser().parse_args(session.posargs)
 
-    session.install(".[docs]")
+    if args.editable:
+        session.install("-e", ".[docs]")
+    else:
+        session.install(".[docs]")
 
     if "html" in args.docs_builders:
         session.run("python", "-m", "sphinx", "-W", *SPHINX_HTML_ARGS)
@@ -186,6 +196,9 @@ def test(session):
 
     install = []
 
+    if args.editable:
+        install.append("-e")
+
     if install_extras:
         install.append(f".[{','.join(install_extras)}]")
     else:
